pub enum Exactness {
Exact,
Approximate,
}Expand description
Declares whether an item is exact B-rep evidence or an approximation.
Variants
Exact
The producer asserts that this is exact geometry evidence.
Approximate
The producer asserts that this evidence is an approximation.